@@ -20,6 +20,7 @@ from switchbee.device import (
     SwitchBeeTimedSwitch,
     SwitchBeeTimerSwitch,
     ThermostatMode,
+    ThermostatTemperatureUnit,
 )
 
 from .utils import timestamp_now
@@ -341,7 +342,7 @@ class CentralUnitAPI:
                         modes=[
                             ThermostatMode(mode) for mode in item[ApiAttribute.MODES]
                         ],
-                        unit=item[ApiAttribute.TEMPERATURE_UNITS],
+                        unit=ThermostatTemperatureUnit(item[ApiAttribute.TEMPERATURE_UNITS]),
                     )
                 # add rolling scenario
                 elif device_type == DeviceType.RollingScenario.value:
